@@ -62,7 +62,7 @@ class CrestMetadata:
     def db_urls(self):
         """
         Once the `Metadata` object is created simply access it like this:
-        >>> print(metadata.db_urls['silvamod']['url'])
+        >>> print(metadata.db_urls['silvamod138']['url'])
         """
         # Download the gist #
         content = retrieve_from_url(self.metadata_url)
@@ -224,9 +224,7 @@ class CrestDatabase:
         1 and 32477.
         """
         # Load the tree with ete3 #
-        tree = Tree(self.path.replace_extension('tre'), format=8)
-        # Add information from the `map` file #
-        return tree
+        return Tree(self.path.replace_extension('tre'), format=8)
 
     @property_cached
     def node_to_name(self):
@@ -249,7 +247,7 @@ class CrestDatabase:
     @property_cached
     def acc_to_node(self):
         """
-        Using the `.map` file, we return a dictionary linking accession numbers
+        Using the `.map` file, we return a dictionary linking accession strings
         to node numbers.
         Example: HQ191339 -> 28386
         """
@@ -279,28 +277,13 @@ class CrestDatabase:
                 'Genus',          # 9
                 'Species']        # 10
 
-###############################################################################
-class Silvamod128(CrestDatabase):
-    """
-    Represents the old silvamod database.
-    """
-
-    short_name = 'silvamod128'
-    long_name  = 'Silva version 128 modified for CREST'
-
-###############################################################################
-class Silvamod138(CrestDatabase):
-    """
-    Represents the new silvamod database.
-    """
-
-    short_name = 'silvamod138'
-    long_name  = 'Silva version 138 modified for CREST'
-
 ###############################################################################
 # As our databases should only be stored on disk once, so we have singletons #
+silvamod138 = CrestDatabase('silvamod138',
+                            'Silva version 138 modified for CREST')
+
 silvamod128 = CrestDatabase('silvamod128',
                             'Silva version 128 modified for CREST')
 
-silvamod138 = CrestDatabase('silvamod138',
-                            'Silva version 138 modified for CREST')
\ No newline at end of file
+bold        = CrestDatabase('bold',
+                            'The BOLD database modified for CREST')
\ No newline at end of file
